Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2285)

Unified Diff: third_party/WebKit/Source/core/xml/parser/XMLDocumentParser.cpp

Issue 1716803002: Trigger repaint on first paint only on pending stylesheet decrement. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « third_party/WebKit/Source/core/paint/BlockPainter.cpp ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/WebKit/Source/core/xml/parser/XMLDocumentParser.cpp
diff --git a/third_party/WebKit/Source/core/xml/parser/XMLDocumentParser.cpp b/third_party/WebKit/Source/core/xml/parser/XMLDocumentParser.cpp
index 84c25a94d6964e00e81c055a24137aef0ef21a84..2d87cd5784e4a66a840126a9904ff9764e4b7a47 100644
--- a/third_party/WebKit/Source/core/xml/parser/XMLDocumentParser.cpp
+++ b/third_party/WebKit/Source/core/xml/parser/XMLDocumentParser.cpp
@@ -39,6 +39,7 @@
#include "core/dom/DocumentType.h"
#include "core/dom/ProcessingInstruction.h"
#include "core/dom/ScriptLoader.h"
+#include "core/dom/StyleEngine.h"
#include "core/dom/TransformSource.h"
#include "core/fetch/FetchInitiatorTypeNames.h"
#include "core/fetch/RawResource.h"
@@ -448,7 +449,7 @@ void XMLDocumentParser::end()
updateLeafTextNode();
// Do not bail out if in a stopped state, but notify document that
// parsing has finished.
- document()->styleResolverChanged();
+ document()->styleEngine().resolverChanged(FullStyleUpdate);
}
if (isParsing())
@@ -1541,9 +1542,9 @@ void XMLDocumentParser::doEnd()
document()->setTransformSource(adoptPtr(new TransformSource(doc)));
// Make the document think it's done, so it will apply XSL stylesheets.
document()->setParsingState(Document::FinishedParsing);
- document()->styleResolverChanged();
+ document()->styleEngine().resolverChanged(FullStyleUpdate);
- // styleResolverChanged() call can detach the parser and null out its
+ // resolverChanged() call can detach the parser and null out its
// document. In that case, we just bail out.
if (isDetached())
return;
« no previous file with comments | « third_party/WebKit/Source/core/paint/BlockPainter.cpp ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698